@@ -22,7 +22,7 @@ from lino.modlib.gfks.mixins import Controllable
 from lino_xl.lib.topics.models import AddInterestField
 from lino.modlib.users.mixins import My, UserAuthored
 from lino.modlib.comments.mixins import Commentable
-from lino.modlib.publisher.mixins import Publishable, PreviewPublication
+from lino.modlib.publisher.mixins import Publishable
 from lino.modlib.publisher.choicelists import PublisherViews
 # from lino.modlib.printing.mixins import PrintableType, TypedPrintable
 from lino.mixins.periods import CombinedDateTime
@@ -36,13 +36,13 @@ from .roles import BlogsReader
 html_parser = etree.HTMLParser()
 
 
-
 class EntryType(mixins.BabelNamed):
 
     templates_group = 'blogs/Entry'
 
-    class Meta:
+    class Meta():
         app_label = 'blogs'
+        abstract = dd.is_abstract_model(__name__, 'EntryType')
         verbose_name = _("Blog Entry Type")
         verbose_name_plural = _("Blog Entry Types")
 
@@ -74,6 +74,7 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
 
     class Meta:
         app_label = 'blogs'
+        abstract = dd.is_abstract_model(__name__, 'Entry')
         verbose_name = _("Blog Entry")
         verbose_name_plural = _("Blog Entries")
 
@@ -85,11 +86,6 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
     entry_type = dd.ForeignKey('blogs.EntryType', blank=True, null=True)
     language = dd.LanguageField()
 
-    publisher_location = "bl"
-    publisher_page_template = "blogs/entry_page.html"
-    # publisher_item_template = "blogs/entry_item.html"
-    preview_publication = PreviewPublication(label=_("Static View"))
-
     def __str__(self):
         if self.title:
             return self.title
@@ -118,12 +114,10 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
         if ar is None:
             return
         return ''.join(ar.row_as_page(self))
-        # return self.render_from(self.publisher_page_template, ar)
 
     def get_item_preview(self, ar):
         if ar is None:
             return
-        # return self.render_from(self.publisher_item_template, ar)
         return ar.row_as_paragraph(self)
 
     @dd.htmlbox()
@@ -283,7 +277,7 @@ class Entries(dd.Table):
     def collect_extra_actions(cls):
         yield dd.WrappedAction(
             rt.models.blogs.PublicEntries.detail_action,
-            label=_("Preview"),
+            label=_("Pretty view"),
             icon_name=None)
 
 
@@ -297,8 +291,6 @@ class PublicEntries(Entries):
 
     display_mode = ((None, constants.DISPLAY_MODE_STORY), )
 
-    list_layout = "item_preview"
-
     @classmethod
     def collect_extra_actions(cls):
         return []
