@@ -51,10 +51,9 @@ class InsertEvent(dd.Action):
     show_in_toolbar = True
 
     def run_from_ui(self, ar, **kw):
-        Event = rt.models.cal.Event
-        sar = Event.get_default_table().insert_action.request_from(ar)
-        sar.known_values = dict(
-            start_date=str(ar.selected_rows[0].date))
+        t = rt.models.cal.Event.get_default_table()
+        sar = t.insert_action.request_from(ar)
+        sar.known_values = dict(start_date=str(ar.selected_rows[0].date))
         ar.set_response(eval_js=ar.renderer.ar2js(sar, None))
 
 class DailyPlannerRows(dd.Table):
