@@ -118,24 +118,24 @@ def objects():
             content_type=ContentType.objects.get_for_model(Person),
             **dd.str2kw('name', _("Terms & conditions")))
 
-    if dd.is_installed('contenttypes'):
-        # TODO: remove this because the feature isn't used. But afterwards adapt
-        # the doctests!
-        ContentType = rt.models.contenttypes.ContentType
-        I = Instantiator('gfks.HelpText',
-                         'content_type field help_text').build
-        t = ContentType.objects.get_for_model(Person)
-
-        #~ yield I(t,'birth_date',u"""\
-    #~ Unkomplette Geburtsdaten sind erlaubt, z.B.
-    #~ <ul>
-    #~ <li>00.00.1980 : irgendwann in 1980</li>
-    #~ <li>00.07.1980 : im Juli 1980</li>
-    #~ <li>23.07.0000 : Geburtstag am 23. Juli, Alter unbekannt</li>
-    #~ </ul>
-    #~ """)
-
-        ct = ContentType.objects.get_for_model(Partner)
-        yield I(ct, 'language', u"""\
-    Die Sprache, in der Dokumente ausgestellt werden sollen.
-    """)
+    # if dd.is_installed('contenttypes'):
+    #     # TODO: remove this because the feature isn't used. But afterwards adapt
+    #     # the doctests!
+    #     ContentType = rt.models.contenttypes.ContentType
+    #     I = Instantiator('gfks.HelpText',
+    #                      'content_type field help_text').build
+    #     t = ContentType.objects.get_for_model(Person)
+    #
+    #     #~ yield I(t,'birth_date',u"""\
+    # #~ Unkomplette Geburtsdaten sind erlaubt, z.B.
+    # #~ <ul>
+    # #~ <li>00.00.1980 : irgendwann in 1980</li>
+    # #~ <li>00.07.1980 : im Juli 1980</li>
+    # #~ <li>23.07.0000 : Geburtstag am 23. Juli, Alter unbekannt</li>
+    # #~ </ul>
+    # #~ """)
+    #
+    #     ct = ContentType.objects.get_for_model(Partner)
+    #     yield I(ct, 'language', u"""\
+    # Die Sprache, in der Dokumente ausgestellt werden sollen.
+    # """)
