@@ -45,10 +45,11 @@ from lino.utils.dates import DateRangeValue
 
 from .choicelists import MeetingStates
 from lino_xl.lib.tickets.choicelists import TicketStates
+from lino.modlib.memo.mixins import MemoReferrable
 
 
 
-class Meeting(Referrable, Milestone, Reservation, Duplicable, Starrable):
+class Meeting(Referrable, Milestone, Reservation, Duplicable, Starrable, MemoReferrable):
     """A Meetings is a list of tickets that are to be discussed with a group of people
     """
     # .. attribute:: max_places
@@ -58,6 +59,7 @@ class Meeting(Referrable, Milestone, Reservation, Duplicable, Starrable):
     #
     # """
     workflow_state_field = 'state'
+    memo_command = 'meeting'
 
     class Meta:
         app_label = 'meetings'
@@ -178,39 +180,39 @@ class Meeting(Referrable, Milestone, Reservation, Duplicable, Starrable):
         return super(Referrable, model).quick_search_filter(search_text, prefix)
 
 
-@dd.receiver(dd.post_startup)
-def setup_memo_commands(sender=None, **kwargs):
-    # See :doc:`/specs/memo`
-
-    if not sender.is_installed('memo'):
-        return
-
-    Meeting = sender.models.meetings.Meeting
-
-    def cmd(parser, s, cmdname, usages):
-        pk = s
-        txt = None
-
-        ar = parser.context['ar']
-        kw = dict()
-        # dd.logger.info("20161019 %s", ar.renderer)
-        pk = int(pk)
-        obj = Meeting.objects.get(pk=pk)
-        # try:
-        # except model.DoesNotExist:
-        #     return "[{} {}]".format(name, s)
-        if txt is None:
-            txt = "{0}".format(obj.name)
-            kw.update(title=obj.name)
-        e = ar.obj2html(obj, txt, **kw)
-        # return str(ar)
-        return tostring(e)
-
-    sender.plugins.memo.parser.register_django_model(
-        'meeting', Meeting,
-        cmd=cmd,
-        # title=lambda obj: obj.name
-    )
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     Meeting = sender.models.meetings.Meeting
+#
+#     def cmd(parser, s, cmdname, usages):
+#         pk = s
+#         txt = None
+#
+#         ar = parser.context['ar']
+#         kw = dict()
+#         # dd.logger.info("20161019 %s", ar.renderer)
+#         pk = int(pk)
+#         obj = Meeting.objects.get(pk=pk)
+#         # try:
+#         # except model.DoesNotExist:
+#         #     return "[{} {}]".format(name, s)
+#         if txt is None:
+#             txt = "{0}".format(obj.name)
+#             kw.update(title=obj.name)
+#         e = ar.obj2html(obj, txt, **kw)
+#         # return str(ar)
+#         return tostring(e)
+#
+#     sender.plugins.memo.parser.register_django_model(
+#         'meeting', Meeting,
+#         cmd=cmd,
+#         # title=lambda obj: obj.name
+#     )
 
 
 from .ui import *
