@@ -484,39 +484,39 @@ dd.update_field(
 
 dd.update_field(Enrolment, 'order', blank=True)
 
-@dd.receiver(dd.post_startup)
-def setup_memo_commands(sender=None, **kwargs):
-    # See :doc:`/specs/memo`
-    if not sender.is_installed('memo'):
-        return
-
-    Order = sender.models.orders.Order
-
-    def cmd(parser, s, cmdname, usages):
-
-        pk = s
-        txt = None
-
-        ar = parser.context['ar']
-        kw = dict()
-        # dd.logger.info("20161019 %s", ar.renderer)
-        pk = int(pk)
-        obj = Order.objects.get(pk=pk)
-        # try:
-        # except model.DoesNotExist:
-        #     return "[{} {}]".format(name, s)
-        if txt is None:
-            txt = "{0}".format(obj.name)
-            kw.update(title=obj.name)
-        e = ar.obj2html(obj, txt, **kw)
-        # return str(ar)
-        return tostring(e)
-
-    sender.plugins.memo.parser.register_django_model(
-        'order', Order,
-        cmd=cmd,
-        # title=lambda obj: obj.name
-    )
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     Order = sender.models.orders.Order
+#
+#     def cmd(parser, s, cmdname, usages):
+#
+#         pk = s
+#         txt = None
+#
+#         ar = parser.context['ar']
+#         kw = dict()
+#         # dd.logger.info("20161019 %s", ar.renderer)
+#         pk = int(pk)
+#         obj = Order.objects.get(pk=pk)
+#         # try:
+#         # except model.DoesNotExist:
+#         #     return "[{} {}]".format(name, s)
+#         if txt is None:
+#             txt = "{0}".format(obj.name)
+#             kw.update(title=obj.name)
+#         e = ar.obj2html(obj, txt, **kw)
+#         # return str(ar)
+#         return tostring(e)
+#
+#     sender.plugins.memo.parser.register_django_model(
+#         'order', Order,
+#         cmd=cmd,
+#         # title=lambda obj: obj.name
+#     )
 
 # class OrderItem(ProductDocItem, SequencedVoucherItem):
 class OrderItem(SequencedVoucherItem):
