@@ -58,10 +58,6 @@ class Page(Hierarchical, Sequenced, Previewable, Publishable):
         verbose_name_plural = _("Nodes")
         unique_together = ["ref", "language"]
 
-    publisher_location = "p"
-    publisher_page_template = "pages/Node/default.pubpage.html"
-    # publisher_item_template = "pages/Node/default.pubitem.html"
-
     ref = models.CharField(
         _("Reference"), max_length=200, blank=True, null=True)
     language = LanguageField(default=models.NOT_PROVIDED, blank=True)
