@@ -23,7 +23,8 @@ def objects():
     try:
         ses = rt.login("robin")
     except rt.models.users.User.DoesNotExist:
-        print("20220621 no robin in ", rt.models.users.User.objects.all())
+        print("20220621 no robin in {} (languages = {})".format(
+            rt.models.users.User.objects.all(), settings.SITE.languages))
         raise
     for year in range(dd.plugins.ledger.start_year, dd.today().year+1):
         sp = AccountingPeriod.get_default_for_date(date(year, 1, 1))
